@@ -1,4 +1,4 @@
-""" You can import gdsfactory.as gf
+"""You can import gdsfactory.as gf.
 
 functions:
     - import_gds(): returns a Component from a GDS
@@ -7,7 +7,6 @@ classes:
 
     - Component
     - Port
-    - CONFIG
     - TECH
 
 modules:
@@ -17,15 +16,16 @@ modules:
 
 isort:skip_file
 """
-from toolz import compose
+from __future__ import annotations
 from functools import partial
-from phidl.device_layout import Group
+from toolz import compose
+from gdsfactory.component_layout import Group
 from gdsfactory.path import Path
 
 
 # NOTE: import order matters. Only change the order if you know what you are doing
 from gdsfactory.component import Component, ComponentReference
-from gdsfactory.config import CONFIG, CONF, call_if_func
+from gdsfactory.config import CONF, call_if_func, PATH
 from gdsfactory.port import Port
 from gdsfactory.cell import cell
 from gdsfactory.cell import cell_without_validator
@@ -36,7 +36,9 @@ from gdsfactory.read.import_gds import import_gds
 from gdsfactory.cross_section import CrossSection, Section
 from gdsfactory.types import Label
 
+from gdsfactory import decorators
 from gdsfactory import cross_section
+from gdsfactory import labels
 from gdsfactory import asserts
 from gdsfactory import components
 from gdsfactory import routing
@@ -47,16 +49,13 @@ from gdsfactory import tech
 from gdsfactory import read
 from gdsfactory import layers
 from gdsfactory import add_termination
-from gdsfactory import add_grating_couplers
 from gdsfactory import functions
 from gdsfactory import export
 from gdsfactory import geometry
-from gdsfactory import mask
 from gdsfactory import add_ports
 from gdsfactory import write_cells
 from gdsfactory import add_pins
 
-from gdsfactory.tech import TECH
 from gdsfactory.add_tapers import add_tapers
 from gdsfactory.add_padding import (
     add_padding,
@@ -73,6 +72,7 @@ from gdsfactory.pdk import (
     get_layer,
     get_active_pdk,
     get_cell,
+    get_constant,
 )
 from gdsfactory.get_factories import get_cells
 from gdsfactory.cross_section import get_cross_section_factories
@@ -81,19 +81,17 @@ from gdsfactory.cross_section import get_cross_section_factories
 c = components
 
 __all__ = (
-    "CONFIG",
     "CONF",
     "Component",
     "ComponentReference",
     "CrossSection",
-    "Section",
-    "compose",
     "Group",
     "LAYER",
+    "Label",
     "Path",
+    "Pdk",
     "Port",
-    "TECH",
-    "add_grating_couplers",
+    "Section",
     "add_padding",
     "add_padding_container",
     "add_pins",
@@ -101,26 +99,36 @@ __all__ = (
     "add_tapers",
     "add_termination",
     "asserts",
-    "geometry",
     "c",
     "call_if_func",
     "cell",
     "cell_without_validator",
     "clear_cache",
     "components",
+    "compose",
     "cross_section",
+    "decorators",
     "export",
     "fill_rectangle",
     "functions",
+    "geometry",
+    "get_active_pdk",
+    "get_cell",
+    "get_cells",
+    "get_component",
+    "get_constant",
+    "get_cross_section",
+    "get_cross_section_factories",
+    "get_layer",
     "get_padding_points",
     "grid",
     "grid_with_text",
     "import_gds",
+    "labels",
     "layers",
-    "mask",
     "pack",
-    "path",
     "partial",
+    "path",
     "read",
     "routing",
     "show",
@@ -128,14 +136,6 @@ __all__ = (
     "tech",
     "types",
     "write_cells",
-    "Label",
-    "Pdk",
-    "get_active_pdk",
-    "get_component",
-    "get_cross_section",
-    "get_cell",
-    "get_cells",
-    "get_layer",
-    "get_cross_section_factories",
+    "PATH",
 )
-__version__ = "5.15.2"
+__version__ = "6.5.0"
