@@ -1,4 +1,4 @@
-"""add_pin adss a Pin to a port, add_pins adds Pins to all ports:
+"""Add_pin adds a Pin to a port, add_pins adds Pins to all ports.
 
 - pins
 - outline
@@ -6,22 +6,25 @@
 Some functions modify a component without changing its name.
 Make sure these functions are inside a new Component or called as a decorator
 They without modifying the cell name
-
 """
+from __future__ import annotations
+
 import json
 from functools import partial
-from typing import Callable, List, Optional, Tuple, Union
+from typing import TYPE_CHECKING, Callable, List, Optional, Tuple, Union
 
-import gdspy
+import gdstk
 import numpy as np
 from numpy import ndarray
 from omegaconf import OmegaConf
-from phidl.device_layout import Device as Component
-from phidl.device_layout import DeviceReference as ComponentReference
-from phidl.device_layout import Port
 
 from gdsfactory.snap import snap_to_grid
 
+if TYPE_CHECKING:
+    from gdsfactory.component import Component
+    from gdsfactory.component_reference import ComponentReference
+    from gdsfactory.port import Port
+
 Layer = Tuple[int, int]
 Layers = Tuple[Layer, ...]
 LayerSpec = Optional[Union[Layer, str, int]]
@@ -33,9 +36,12 @@ def _rotate(v: ndarray, m: ndarray) -> ndarray:
     return np.dot(m, v)
 
 
-def get_pin_triangle_polygon_tip(port: Port) -> Tuple[List[float], Tuple[float, float]]:
-    """Returns triangle polygon and tip position"""
+def get_pin_triangle_polygon_tip(
+    port: Port,
+) -> Tuple[List[float], Tuple[float, float]]:
+    """Returns triangle polygon and tip position."""
     p = port
+    port_face = p.info.get("face", None)
 
     orientation = p.orientation
 
@@ -47,15 +53,22 @@ def get_pin_triangle_polygon_tip(port: Port) -> Tuple[List[float], Tuple[float,
     rot_mat = np.array([[ca, -sa], [sa, ca]])
     d = p.width / 2
 
-    dbot = np.array([0, -d])
-    dtop = np.array([0, d])
     dtip = np.array([d, 0])
 
+    if port_face:
+        dtop = port_face[0]
+        dbot = port_face[-1]
+    else:
+        dbot = np.array([0, -d])
+        dtop = np.array([0, d])
+
     p0 = p.center + _rotate(dbot, rot_mat)
     p1 = p.center + _rotate(dtop, rot_mat)
+    port_face = [p0, p1]
+
     ptip = p.center + _rotate(dtip, rot_mat)
 
-    polygon = [p0, p1, ptip]
+    polygon = list(port_face) + [ptip]
     polygon = np.stack(polygon)
     return polygon, ptip
 
@@ -66,7 +79,7 @@ def add_pin_triangle(
     layer: LayerSpec = "PORT",
     layer_label: LayerSpec = "TEXT",
 ) -> None:
-    """Add triangle pin with a right angle, pointing out of the port
+    """Add triangle pin with a right angle, pointing out of the port.
 
     Args:
         component: to add pin.
@@ -93,7 +106,7 @@ def add_pin_rectangle_inside(
     layer: LayerSpec = "PORT",
     layer_label: LayerSpec = "TEXT",
 ) -> None:
-    """Add square pin towards the inside of the port
+    """Add square pin towards the inside of the port.
 
     Args:
         component: to add pins.
@@ -113,8 +126,6 @@ def add_pin_rectangle_inside(
           |               |
           |      __       |
           |_______________|
-
-
     """
     p = port
     a = p.orientation
@@ -171,7 +182,6 @@ def add_pin_rectangle_double(
           |      __       |
           |_______________|
                  __
-
     """
     p = port
     a = p.orientation
@@ -233,7 +243,6 @@ def add_pin_rectangle(
         layer_label: for the label.
         port_margin: margin to port edge.
 
-
     .. code::
 
            _______________
@@ -246,7 +255,6 @@ def add_pin_rectangle(
           |      __       |
           |_______________|
                  __
-
     """
     p = port
     a = p.orientation
@@ -294,7 +302,6 @@ def add_pin_path(
         layer: for the pin marker.
         layer_label: optional layer label. Defaults to layer.
 
-
     .. code::
 
            _______________
@@ -307,7 +314,6 @@ def add_pin_path(
           |      __       |
           |_______________|
                  __
-
     """
     from gdsfactory.pdk import get_layer
 
@@ -326,8 +332,13 @@ def add_pin_path(
 
     points = [p0, p1]
     layer = get_layer(layer)
-    path = gdspy.FlexPath(
-        points=points, width=p.width, layer=layer[0], datatype=layer[1], gdsii_path=True
+    path = gdstk.FlexPath(
+        points,
+        width=p.width,
+        layer=layer[0],
+        datatype=layer[1],
+        simple_path=True,
+        tolerance=1e-3,
     )
     component.add(path)
 
@@ -375,8 +386,8 @@ def add_pins_siepic(
     """Add pins.
 
     Enables you to run SiEPIC verification tools:
-    To Run verification install SiEPIC-tools klayout package
-    then hit V shortcut in klayout to run verification
+    To Run verification install SiEPIC-tools KLayout package
+    then hit V shortcut in KLayout to run verification
 
     - ensure no disconnected pins
     - netlist extraction
@@ -387,9 +398,7 @@ def add_pins_siepic(
         port_type: optical, electrical, ...
         layer_pin: pin layer.
         pin_length: length of the pin marker for the port.
-
     """
-
     for p in component.get_ports_list(port_type=port_type):
         function(component=component, port=p, layer=layer_pin, pin_length=pin_length)
 
@@ -420,14 +429,14 @@ def add_bbox_siepic(
     layers = component.get_layers()
 
     if bbox_layer and bbox_layer in layers:
-        component.remove_layers(layers=(bbox_layer,))
+        component.remove_layers(layers=(bbox_layer,), recursive=False)
 
     remove_layers = remove_layers or []
 
     for layer in remove_layers:
         layer = get_layer(layer)
         if layer in layers:
-            component.remove_layers(layers=(layer,))
+            component.remove_layers(layers=(layer,), recursive=False)
 
     if bbox_layer:
         component.add_padding(default=0, layers=(bbox_layer,))
@@ -454,7 +463,6 @@ def add_pins_bbox_siepic(
         bbox_layer: bounding box layer.
         padding: around device.
     """
-    component = component.copy()
     layers = component.get_layers()
     remove_layers = (layer_pin, bbox_layer)
 
@@ -495,7 +503,6 @@ def add_pins(
         function: to add each pin.
         select_ports: function to select_ports.
         kwargs: add pins function settings.
-
     """
     reference = reference or component
     ports = (
@@ -509,6 +516,7 @@ def add_pins(
 
 
 add_pins_triangle = partial(add_pins, function=add_pin_triangle)
+add_pins_center = partial(add_pins, function=add_pin_rectangle)
 
 
 def add_settings_label(
@@ -516,13 +524,12 @@ def add_settings_label(
     reference: ComponentReference,
     layer_label: LayerSpec = "LABEL_SETTINGS",
 ) -> None:
-    """Add settings in label
+    """Add settings in label.
 
     Args:
-        componnent: to add pins.
+        component: to add pins.
         reference: ComponentReference.
         layer_label: layer spec.
-
     """
     from gdsfactory.pdk import get_layer
 
@@ -544,7 +551,6 @@ def add_instance_label(
     layer: LayerSpec = "LABEL_INSTANCE",
 ) -> None:
     """Adds label to a reference in a component."""
-
     instance_name = (
         instance_name
         or f"{reference.parent.name},{int(reference.x)},{int(reference.y)}"
@@ -561,13 +567,13 @@ def add_instance_label(
 
 def add_pins_and_outline(
     component: Component,
-    reference: ComponentReference,
+    reference: Optional[ComponentReference] = None,
     add_outline_function: Optional[Callable] = add_outline,
     add_pins_function: Optional[Callable] = add_pins,
     add_settings_function: Optional[Callable] = add_settings_label,
     add_instance_label_function: Optional[Callable] = add_settings_label,
 ) -> None:
-    """Add markers:
+    """Add markers.
 
     - outline
     - pins for the ports
@@ -581,7 +587,6 @@ def add_pins_and_outline(
         add_pins_function: to add pins to ports.
         add_settings_function: to add outline around the component.
         add_instance_label_function: labels each instance.
-
     """
     if add_outline_function:
         add_outline_function(component=component, reference=reference)
@@ -604,7 +609,7 @@ if __name__ == "__main__":
     # p2 = len(c2.get_polygons())
     # assert p2 == p1 + 2
     # c1 = gf.components.straight_heater_metal(length=2)
-    c = gf.components.ring_single()
+    c = gf.components.straight(decorator=add_pins)
     # cc.show(show_ports=False)
     c.show(show_subports=True)
     c.show(show_ports=True)
