@@ -1,4 +1,6 @@
-"""add ports from pin markers or labels."""
+"""Add ports from pin markers or labels."""
+from __future__ import annotations
+
 from functools import partial
 from typing import Optional, Tuple
 
@@ -36,7 +38,6 @@ def add_ports_from_markers_square(
         port_names: names of the ports (defaults to {i}).
         port_name_prefix: defaults to 'o' for optical and 'e' for electrical.
         port_type: optical, electrical.
-
     """
     port_name_prefix_default = "o" if port_type == "optical" else "e"
     port_name_prefix = port_name_prefix or port_name_prefix_default
@@ -47,11 +48,14 @@ def add_ports_from_markers_square(
     layer = port_layer or pin_layer
 
     for port_name, p in zip(port_names, port_markers.polygons):
-        dy = snap_to_grid(p.ymax - p.ymin)
-        dx = snap_to_grid(p.xmax - p.xmin)
+        (xmin, ymin), (xmax, ymax) = p.bounding_box()
+        x, y = np.sum(p.bounding_box(), 0) / 2
+
+        dy = snap_to_grid(ymax - ymin)
+        dx = snap_to_grid(xmax - xmin)
         if dx == dy and max_pin_area_um2 > dx * dy > min_pin_area_um2:
-            x = p.x
-            y = p.y
+            x = x
+            y = y
             component.add_port(
                 port_name,
                 center=(x, y),
@@ -118,7 +122,6 @@ def add_ports_from_markers_center(
           |_____|__|______|
                 |__|
 
-
     For inside=True all the pin is inside the port
 
     .. code::
@@ -132,8 +135,6 @@ def add_ports_from_markers_center(
           |      __       |
           |_____|__|______|
 
-
-
     dx < dy: port is east or west
         x > xc: east
         x < xc: west
@@ -145,7 +146,6 @@ def add_ports_from_markers_center(
     dx = dy
         x > xc: east
         x < xc: west
-
     """
     xc = xcenter or component.x
     yc = ycenter or component.y
@@ -165,10 +165,11 @@ def add_ports_from_markers_center(
 
     for i, p in enumerate(port_markers.polygons):
         port_name = f"{port_name_prefix}{i+1}" if port_name_prefix else str(i)
-        dy = p.ymax - p.ymin
-        dx = p.xmax - p.xmin
-        x = p.x
-        y = p.y
+        (xmin, ymin), (xmax, ymax) = p.bounding_box()
+        x, y = np.sum(p.bounding_box(), 0) / 2
+
+        dy = ymax - ymin
+        dx = xmax - xmin
 
         if min_pin_area_um2 and dx * dy < min_pin_area_um2:
             if debug:
@@ -183,10 +184,10 @@ def add_ports_from_markers_center(
                 print(f"skipping square port at ({x}, {y})")
             continue
 
-        pxmax = p.xmax
-        pxmin = p.xmin
-        pymax = p.ymax
-        pymin = p.ymin
+        pxmax = xmax
+        pxmin = xmin
+        pymax = ymax
+        pymin = ymin
 
         orientation = 0
 
@@ -194,47 +195,47 @@ def add_ports_from_markers_center(
             if x > xc:  # east
                 orientation = 0
                 width = dy
-                x = p.xmax if inside else p.x
+                x = xmax if inside else x
             elif x < xc:  # west
                 orientation = 180
                 width = dy
-                x = p.xmin if inside else p.x
+                x = xmin if inside else x
         elif dy > dx if short_ports else dx > dy:
             if y > yc:  # north
                 orientation = 90
                 width = dx
-                y = p.ymax if inside else p.y
+                y = ymax if inside else y
             elif y < yc:  # south
                 orientation = 270
                 width = dx
-                y = p.ymin if inside else p.y
+                y = ymin if inside else y
 
         elif pxmax > xmax - tol:  # east
             orientation = 0
             width = dy
-            x = p.xmax if inside else p.x
+            x = xmax if inside else x
         elif pxmin < xmin + tol:  # west
             orientation = 180
             width = dy
-            x = p.xmin if inside else p.x
+            x = xmin if inside else x
         elif pymax > ymax - tol:  # north
             orientation = 90
             width = dx
-            y = p.ymax if inside else p.y
+            y = ymax if inside else y
         elif pymin < ymin + tol:  # south
             orientation = 270
             width = dx
-            y = p.ymin if inside else p.y
+            y = ymin if inside else y
 
         elif pxmax > xc:
             orientation = 0
             width = dy
-            x = p.xmax if inside else p.x
+            x = xmax if inside else x
 
         elif pxmax < xc:
             orientation = 180
             width = dy
-            x = p.xmin if inside else p.x
+            x = xmin if inside else x
 
         x = snap_to_grid(x)
         y = snap_to_grid(y)
@@ -301,20 +302,19 @@ def add_ports_from_labels(
             if False adds incremental suffix (1, 2 ...) to port name.
         port_orientation: None for electrical ports.
         guess_port_orientation: assumes right: 0, left: 180, top: 90, bot: 270.
-
     """
     port_name_prefix_default = "o" if port_type == "optical" else "e"
     port_name_prefix = port_name_prefix or port_name_prefix_default
-    xc = xcenter or component.x
     yc = component.y
 
     port_name_to_index = {}
 
+    xc = xcenter or component.x
     for i, label in enumerate(component.labels):
-        x, y = label.position
+        x, y = label.origin
 
-        if layer_label and not (
-            layer_label[0] == label.layer and layer_label[1] == label.texttype
+        if layer_label and (
+            layer_label[0] != label.layer or layer_label[1] != label.texttype
         ):
             continue
 
@@ -367,7 +367,7 @@ def add_ports_from_siepic_pins(
     pin_layer_electrical: LayerSpec = "PORTE",
     port_layer_electrical: Optional[LayerSpec] = None,
 ) -> Component:
-    """Add ports from SiEPIC-type cells.
+    """Add ports from SiEPIC-type cells, where the pins are defined as paths.
 
     Looks for label, path pairs.
 
@@ -380,11 +380,20 @@ def add_ports_from_siepic_pins(
     """
     pin_layers = {"optical": pin_layer_optical, "electrical": pin_layer_electrical}
 
+    import gdsfactory as gf
+
+    pin_layer_optical = gf.get_layer(pin_layer_optical)
+    port_layer_optical = gf.get_layer(port_layer_optical)
+    pin_layer_electrical = gf.get_layer(pin_layer_electrical)
+    port_layer_electrical = gf.get_layer(port_layer_electrical)
+
     c = component
     labels = c.get_labels()
 
     for path in c.paths:
-        p1, p2 = path.points
+        p1, p2 = path.spine()
+
+        path_layers = list(zip(path.layers, path.datatypes))
 
         # Find the center of the path
         center = (p1 + p2) / 2
@@ -393,19 +402,21 @@ def add_ports_from_siepic_pins(
         label = None
         for i, l in enumerate(labels):
             if (
-                all(isclose(l.position, center))
-                or all(isclose(l.position, p1))
-                or all(isclose(l.position, p2))
+                all(isclose(l.origin, center))
+                or all(isclose(l.origin, p1))
+                or all(isclose(l.origin, p2))
             ):
                 label = l
                 labels.pop(i)
         if label is None:
-            print(f"Warning: label not found for path: ({p1}, {p2})")
+            print(
+                f"Warning: label not found for path: in center={center} p1={p1} p2={p2}"
+            )
             continue
-        if pin_layer_optical[0] in path.layers:
+        if pin_layer_optical in path_layers:
             port_type = "optical"
             port_layer = port_layer_optical or None
-        elif pin_layer_electrical[0] in path.layers:
+        elif pin_layer_electrical in path_layers:
             port_type = "electrical"
             port_layer = port_layer_electrical or None
         else:
@@ -423,11 +434,10 @@ def add_ports_from_siepic_pins(
         port = Port(
             name=port_name,
             center=center,
-            width=path.widths[0][0],
+            width=path.widths()[0][0],
             orientation=angle,
             layer=port_layer or pin_layers[port_type],
             port_type=port_type,
         )
-
         c.add_port(port)
     return c
