@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import Tuple
 
 import gdsfactory as gf
@@ -13,7 +15,7 @@ def C(
 ) -> Component:
     """C geometry with ports on both ends.
 
-    Adapted from phidl.
+    based on phidl.
 
     Args:
         width: of the line.
@@ -29,7 +31,6 @@ def C(
         |  |___
         ||<---> size[0]
         |______ o2
-
     """
     layer = gf.get_layer(layer)
     c = Component()
