@@ -1,10 +1,18 @@
 """Each component factory component returns a component.
+
 Make sure your components get imported here so the PDK registers them.
 """
 
+from __future__ import annotations
+
 import sys
 
-from gdsfactory.components.add_fidutials import add_fidutials, add_fidutials_offsets
+from gdsfactory.components.add_fiducials import add_fiducials, add_fiducials_offsets
+from gdsfactory.components.add_grating_couplers import (
+    add_grating_couplers,
+    add_grating_couplers_with_loopback_fiber_array,
+    add_grating_couplers_with_loopback_fiber_single,
+)
 from gdsfactory.components.align import add_frame, align_wafer
 from gdsfactory.components.array_component import array
 from gdsfactory.components.array_with_fanout import (
@@ -24,11 +32,16 @@ from gdsfactory.components.bend_euler import (
 )
 from gdsfactory.components.bend_port import bend_port
 from gdsfactory.components.bend_s import bend_s
+from gdsfactory.components.bezier import bezier
 from gdsfactory.components.C import C
 from gdsfactory.components.cavity import cavity
 from gdsfactory.components.cdc import cdc
 from gdsfactory.components.cdsem_all import cdsem_all
 from gdsfactory.components.circle import circle
+from gdsfactory.components.coh_rx_dual_pol import coh_rx_dual_pol
+from gdsfactory.components.coh_rx_single_pol import coh_rx_single_pol
+from gdsfactory.components.coh_tx_dual_pol import coh_tx_dual_pol
+from gdsfactory.components.coh_tx_single_pol import coh_tx_single_pol
 from gdsfactory.components.compass import compass
 from gdsfactory.components.component_lattice import component_lattice
 from gdsfactory.components.component_sequence import component_sequence
@@ -51,6 +64,7 @@ from gdsfactory.components.crossing_waveguide import (
     crossing_etched,
     crossing_from_taper,
 )
+from gdsfactory.components.cutback_2x2 import cutback_2x2
 from gdsfactory.components.cutback_bend import (
     cutback_bend,
     cutback_bend90,
@@ -63,6 +77,7 @@ from gdsfactory.components.cutback_component import (
     cutback_component,
     cutback_component_mirror,
 )
+from gdsfactory.components.cutback_splitter import cutback_splitter
 from gdsfactory.components.dbr import dbr
 from gdsfactory.components.dbr_tapered import dbr_tapered
 from gdsfactory.components.delay_snake import delay_snake
@@ -84,8 +99,12 @@ from gdsfactory.components.extend_ports_list import extend_ports_list
 from gdsfactory.components.extension import extend_port, extend_ports
 from gdsfactory.components.fiber import fiber
 from gdsfactory.components.fiber_array import fiber_array
+from gdsfactory.components.fiducial_squares import fiducial_squares
+from gdsfactory.components.ge_detector_straight_si_contacts import (
+    ge_detector_straight_si_contacts,
+)
 from gdsfactory.components.grating_coupler_array import grating_coupler_array
-from gdsfactory.components.grating_coupler_circular import grating_coupler_circular
+from gdsfactory.components.grating_coupler_dual_pol import grating_coupler_dual_pol
 from gdsfactory.components.grating_coupler_elliptical import (
     ellipse_arc,
     grating_coupler_elliptical,
@@ -96,6 +115,7 @@ from gdsfactory.components.grating_coupler_elliptical import (
 )
 from gdsfactory.components.grating_coupler_elliptical_arbitrary import (
     grating_coupler_elliptical_arbitrary,
+    grating_coupler_elliptical_uniform,
 )
 from gdsfactory.components.grating_coupler_elliptical_lumerical import (
     grating_coupler_elliptical_lumerical,
@@ -134,10 +154,11 @@ from gdsfactory.components.logo import logo
 from gdsfactory.components.loop_mirror import loop_mirror
 from gdsfactory.components.mmi1x2 import mmi1x2
 from gdsfactory.components.mmi2x2 import mmi2x2
+from gdsfactory.components.mmi_90degree_hybrid import mmi_90degree_hybrid
 from gdsfactory.components.mzi import mzi, mzi1x2_2x2, mzi2x2_2x2, mzi_coupler
 from gdsfactory.components.mzi_arm import mzi_arm
 from gdsfactory.components.mzi_arms import mzi_arms
-from gdsfactory.components.mzi_lattice import mzi_lattice
+from gdsfactory.components.mzi_lattice import mzi_lattice, mzi_lattice_mmi
 from gdsfactory.components.mzi_pads_center import mzi_pads_center
 from gdsfactory.components.mzi_phase_shifter import (
     mzi_phase_shifter,
@@ -146,6 +167,9 @@ from gdsfactory.components.mzi_phase_shifter import (
 from gdsfactory.components.mzit import mzit
 from gdsfactory.components.mzit_lattice import mzit_lattice
 from gdsfactory.components.nxn import nxn
+from gdsfactory.components.optimal_90deg import optimal_90deg
+from gdsfactory.components.optimal_hairpin import optimal_hairpin
+from gdsfactory.components.optimal_step import optimal_step
 from gdsfactory.components.pack_doe import generate_doe, pack_doe, pack_doe_grid
 from gdsfactory.components.pad import (
     pad,
@@ -170,10 +194,14 @@ from gdsfactory.components.ring_single_array import ring_single_array
 from gdsfactory.components.ring_single_dut import ring_single_dut, taper2
 from gdsfactory.components.ring_single_heater import ring_single_heater
 from gdsfactory.components.seal_ring import seal_ring
-from gdsfactory.components.spiral import spiral
-from gdsfactory.components.spiral_circular import spiral_circular
+from gdsfactory.components.snspd import snspd
 from gdsfactory.components.spiral_double import spiral_double
 from gdsfactory.components.spiral_external_io import spiral_external_io
+from gdsfactory.components.spiral_heater import (
+    spiral_racetrack,
+    spiral_racetrack_heater_doped,
+    spiral_racetrack_heater_metal,
+)
 from gdsfactory.components.spiral_inner_io import (
     spiral_inner_io,
     spiral_inner_io_fiber_single,
@@ -203,8 +231,10 @@ from gdsfactory.components.taper import (
     taper_strip_to_ridge,
     taper_strip_to_ridge_trenches,
 )
+from gdsfactory.components.taper_adiabatic import taper_adiabatic
 from gdsfactory.components.taper_cross_section import (
     taper_cross_section_linear,
+    taper_cross_section_parabolic,
     taper_cross_section_sine,
 )
 from gdsfactory.components.taper_from_csv import (
@@ -218,6 +248,7 @@ from gdsfactory.components.taper_from_csv import (
 )
 from gdsfactory.components.taper_parabolic import taper_parabolic
 from gdsfactory.components.text import text, text_lines
+from gdsfactory.components.text_freetype import text_freetype
 from gdsfactory.components.text_rectangular import (
     text_rectangular,
     text_rectangular_multi_layer,
@@ -235,7 +266,7 @@ from gdsfactory.components.via_stack import (
 )
 from gdsfactory.components.via_stack_slot import via_stack_slot, via_stack_slot_m1_m2
 from gdsfactory.components.via_stack_with_offset import via_stack_with_offset
-from gdsfactory.components.waveguide_template import strip
+from gdsfactory.components.wafer import wafer
 from gdsfactory.components.wire import wire_corner, wire_straight
 from gdsfactory.components.wire_sbend import wire_sbend
 from gdsfactory.get_factories import get_cells
@@ -256,6 +287,7 @@ _factory_passives = dict(
     crossing45=crossing45,
     taper_cross_section_linear=taper_cross_section_linear,
     taper_cross_section_sine=taper_cross_section_sine,
+    taper_cross_section_parabolic=taper_cross_section_parabolic,
     taper=taper,
     taper2=taper2,
     taper_0p5_to_3_l36=taper_0p5_to_3_l36,
@@ -273,9 +305,12 @@ _factory_passives = dict(
 __all__ = [
     "C",
     "L",
-    "add_fidutials",
-    "add_fidutials_offsets",
+    "add_fiducials",
+    "add_fiducials_offsets",
     "add_frame",
+    "add_grating_couplers",
+    "add_grating_couplers_with_loopback_fiber_array",
+    "add_grating_couplers_with_loopback_fiber_single",
     "align_wafer",
     "array",
     "array_with_fanout",
@@ -293,6 +328,7 @@ __all__ = [
     "bend_port",
     "bend_s",
     "bend_straight_bend",
+    "bezier",
     "cavity",
     "cdsem_all",
     "circle",
@@ -310,6 +346,10 @@ __all__ = [
     "via_stack_slot_m1_m2",
     "via_stack_with_offset",
     "copy_layers",
+    "coh_tx_dual_pol",
+    "coh_tx_single_pol",
+    "coh_rx_dual_pol",
+    "coh_rx_single_pol",
     "coupler",
     "coupler90",
     "coupler90bend",
@@ -333,6 +373,8 @@ __all__ = [
     "cutback_bend90circular",
     "cutback_component",
     "cutback_component_mirror",
+    "cutback_splitter",
+    "cutback_2x2",
     "dbr",
     "dbr_tapered",
     "delay_snake",
@@ -351,12 +393,14 @@ __all__ = [
     "extend_ports_list",
     "fiber",
     "fiber_array",
+    "fiducial_squares",
     "text_lines",
+    "ge_detector_straight_si_contacts",
     "generate_doe",
     "grating_coupler_array",
-    "grating_coupler_circular",
     "grating_coupler_elliptical",
     "grating_coupler_elliptical_arbitrary",
+    "grating_coupler_elliptical_uniform",
     "grating_coupler_elliptical_lumerical",
     "grating_coupler_elliptical_te",
     "grating_coupler_elliptical_tm",
@@ -370,6 +414,7 @@ __all__ = [
     "grating_coupler_te",
     "grating_coupler_tm",
     "grating_coupler_tree",
+    "grating_coupler_dual_pol",
     "grating_taper_points",
     "grating_tooth_points",
     "hline",
@@ -381,6 +426,8 @@ __all__ = [
     "loss_deembedding_ch12_34",
     "loss_deembedding_ch13_24",
     "loss_deembedding_ch14_23",
+    "mmi_90degree_hybrid",
+    "mmi1x2",
     "mmi1x2",
     "mmi2x2",
     "mzi",
@@ -391,11 +438,16 @@ __all__ = [
     "mzi_coupler",
     "mzi_arm",
     "mzi_lattice",
+    "mzi_lattice_mmi",
     "mzi_phase_shifter",
     "mzi_phase_shifter_top_heater_metal",
     "mzit",
     "mzit_lattice",
     "nxn",
+    "optimal_90deg",
+    "optimal_hairpin",
+    "optimal_step",
+    "snspd",
     "pack_doe_grid",
     "pack_doe",
     "pad",
@@ -423,8 +475,6 @@ __all__ = [
     "ring_single_array",
     "ring_single_dut",
     "seal_ring",
-    "spiral",
-    "spiral_circular",
     "spiral_double",
     "spiral_external_io",
     "spiral_inner_io",
@@ -446,9 +496,12 @@ __all__ = [
     "straight_pn",
     "straight_rib",
     "straight_rib_tapered",
-    "strip",
     "switch_tree",
+    "spiral_racetrack",
+    "spiral_racetrack_heater_metal",
+    "spiral_racetrack_heater_doped",
     "taper",
+    "taper_adiabatic",
     "taper2",
     "taper_0p5_to_3_l36",
     "taper_from_csv",
@@ -462,6 +515,7 @@ __all__ = [
     "taper_w11_l200",
     "taper_w12_l200",
     "text",
+    "text_freetype",
     "text_rectangular",
     "text_rectangular_multi_layer",
     "triangle",
@@ -475,6 +529,7 @@ __all__ = [
     "via_cutback",
     "viac",
     "via_corner",
+    "wafer",
     "wire_corner",
     "wire_sbend",
     "wire_straight",
