@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from functools import partial
 from typing import Any, Dict, Optional
 
@@ -6,7 +8,7 @@ from gdsfactory.component import Component
 from gdsfactory.components.grating_coupler_elliptical_arbitrary import (
     grating_coupler_elliptical_arbitrary,
 )
-from gdsfactory.config import CONFIG
+from gdsfactory.config import PATH
 from gdsfactory.types import Floats, LayerSpec
 
 parameters = (
@@ -75,7 +77,7 @@ def grating_coupler_elliptical_lumerical(
     bias_gap: float = 0,
     **kwargs,
 ) -> Component:
-    """Returns a grating coupler from lumerical inverse design 3D optimization
+    """Returns a grating coupler from lumerical inverse design 3D optimization.
 
     this is a wrapper of components.grating_coupler_elliptical_arbitrary
     https://support.lumerical.com/hc/en-us/articles/1500000306621
@@ -117,7 +119,6 @@ def grating_coupler_elliptical_lumerical(
         fiber_marker_layer: in um.
         spiked: grating teeth include sharp spikes to avoid non-manhattan drc errors.
         cross_section: cross_section spec for waveguide port.
-
     """
     parameters = (
         parameters.strip().split() if isinstance(parameters, str) else parameters
@@ -163,7 +164,7 @@ def _compare() -> Component:
     c1 = c << grating_coupler_elliptical_lumerical_etch70(
         layer=(2, 0), layer_slab=None, fiber_angle=5
     )
-    c2 = c << gf.import_gds(CONFIG["gdsdir"] / "gc.gds")
+    c2 = c << gf.import_gds(PATH.gdsdir / "gc.gds")
     c2.xmin = 0
     c1.xmin = 0.7
     return c
