@@ -1,11 +1,13 @@
+from __future__ import annotations
+
 from typing import Optional
 
 import numpy as np
 
 import gdsfactory as gf
 from gdsfactory.component import Component
-from gdsfactory.components.rectangle import rectangle
 from gdsfactory.components.taper import taper as taper_function
+from gdsfactory.snap import snap_to_grid
 from gdsfactory.types import ComponentSpec, CrossSectionSpec, Floats, LayerSpec
 
 _gaps = (0.2,) * 10
@@ -28,9 +30,7 @@ def grating_coupler_rectangular_arbitrary(
     cross_section: CrossSectionSpec = "strip",
     **kwargs,
 ) -> Component:
-    r"""Grating coupler uniform with rectangular shape (not elliptical).
-    Therefore it needs a longer taper.
-    Grating teeth are straight instead of elliptical.
+    r"""Grating coupler uniform with rectangular shape (not elliptical). Therefore it needs a longer taper. Grating teeth are straight instead of elliptical.
 
     Args:
         gaps: list of gaps between grating teeth.
@@ -97,19 +97,25 @@ def grating_coupler_rectangular_arbitrary(
     widths = gf.snap.snap_to_grid(widths)
     gaps = gf.snap.snap_to_grid(gaps)
 
+    y0 = width_grating / 2
+
     for width, gap in zip(widths, gaps):
-        xi += gap + width / 2
-        cgrating = c.add_ref(
-            rectangle(
-                size=(width, width_grating),
-                layer=layer,
-                port_type=None,
-                centered=True,
+        xi += gap
+        points = snap_to_grid(
+            np.array(
+                [
+                    [xi, -y0],
+                    [xi, +y0],
+                    [xi + width, +y0],
+                    [xi + width, -y0],
+                ]
             )
         )
-        cgrating.x = gf.snap.snap_to_grid(xi)
-        cgrating.y = 0
-        xi += width / 2
+        c.add_polygon(
+            points,
+            layer,
+        )
+        xi += width
 
     if layer_slab:
         slab_xmin += length_taper
