@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.types import LayerSpec
@@ -10,7 +12,7 @@ def hline(
     layer: LayerSpec = "WG",
     port_type: str = "optical",
 ) -> Component:
-    """Horizontal line straight, with ports on east and west sides"""
+    """Horizontal line straight, with ports on east and west sides."""
     c = gf.Component()
     if length > 0 and width > 0:
         a = width / 2
