@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import Tuple
 
 import gdsfactory as gf
@@ -17,7 +19,7 @@ def litho_ruler(
 
     Includes marks of varying scales to allow for easy reading by eye.
 
-    adapted from phidl.geometry
+    based on phidl.geometry
 
     Args:
         height: Height of the ruling marks in um.
@@ -26,10 +28,8 @@ def litho_ruler(
         scale: Height scale pattern of marks.
         num_marks: Total number of marks to generate.
         layer: Specific layer to put the ruler geometry on.
-
     """
-
-    D = gf.Component("litho_ruler")
+    D = gf.Component()
     for n in range(num_marks):
         h = height * scale[n % len(scale)]
         D << gf.components.rectangle(size=(width, h), layer=layer)
