@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import Tuple
 
 import gdsfactory as gf
@@ -13,17 +15,16 @@ def litho_steps(
     height: float = 100.0,
     layer: LayerSpec = "WG",
 ) -> Component:
-    """Positive + negative tone linewidth test
+    """Positive + negative tone linewidth test.
 
     used for lithography resolution test patterning
-    adapted from phidl
+    based on phidl
 
     Args:
         line_widths: in um.
         line_spacing: in um.
         height: in um.
         layer: Specific layer to put the ruler geometry on.
-
     """
     D = gf.Component()
 
@@ -33,6 +34,7 @@ def litho_steps(
     )
 
     D.add_ref(T1).rotate(90).movex(-height / 10)
+
     R1 = pc.rectangle(size=(line_spacing, height), layer=layer)
     D.add_ref(R1).movey(-height)
     count = 0
