@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import numpy as np
 
 import gdsfactory as gf
@@ -18,7 +20,7 @@ def nxn(
     wg_margin: float = 1.0,
     **kwargs,
 ) -> Component:
-    """returns a nxn component with nxn ports (west, east, north, south)
+    """Returns a nxn component with nxn ports (west, east, north, south).
 
     Args:
         west: number of west ports.
@@ -31,7 +33,6 @@ def nxn(
         wg_margin: margin from straight to component edge.
         kwargs: port_settings.
 
-
     .. code::
 
             3   4
@@ -41,7 +42,6 @@ def nxn(
         1 -|______|- 6
             |   |
             8   7
-
     """
     c = gf.Component()
     c << gf.components.rectangle(size=(xsize, ysize), layer=layer)
@@ -56,6 +56,7 @@ def nxn(
             )
         )
         orientation = 180
+        y = gf.snap.snap_to_grid(y)
 
         for i, yi in enumerate(y):
             c.add_port(
@@ -77,6 +78,7 @@ def nxn(
             )
         )
         orientation = 0
+        y = gf.snap.snap_to_grid(y)
 
         for i, yi in enumerate(y):
             c.add_port(
@@ -98,6 +100,7 @@ def nxn(
             )
         )
         orientation = 90
+        x = gf.snap.snap_to_grid(x)
 
         for i, xi in enumerate(x):
             c.add_port(
@@ -118,6 +121,7 @@ def nxn(
             )
         )
         orientation = 270
+        x = gf.snap.snap_to_grid(x)
 
         for i, xi in enumerate(x):
             c.add_port(
@@ -134,6 +138,7 @@ def nxn(
 
 
 if __name__ == "__main__":
-    c = nxn(north=1.3, south=3)
+    # c = nxn(north=1.3, south=3)
+    c = nxn()
     # c = gf.components.extension.extend_ports(component=c)
     c.show(show_ports=True)
