@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import Optional, Tuple
 
 import numpy as np
@@ -21,19 +23,20 @@ def rectangle_with_slits(
     slit_spacing: Float2 = (20, 20),
     slit_enclosure: float = 10,
 ) -> Component:
-    """Returns a rectangle with slits. Metal slits reduce stress.
+    """Returns a rectangle with slits.
+
+    Metal slits reduce stress.
 
     Args:
         size: (tuple) Width and height of rectangle.
         layer: Specific layer to put polygon geometry on.
-        layer_slit: does a boolan NOT when None.
+        layer_slit: does a boolean NOT when None.
         centered: True sets center to (0, 0), False sets south-west to (0, 0)
         port_type: for the rectangle.
         slit_size: x, y slit size.
         slit_spacing: pitch_x, pitch_y for slits.
         slit_enclosure: from slit to rectangle edge.
 
-
     .. code::
 
         slit_enclosure
@@ -55,8 +58,6 @@ def rectangle_with_slits(
         |            slit_size[0]           |
         |___________________________________|
                         size[0]
-
-
     """
     c = Component()
     layer = gf.get_layer(layer)
