@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import Tuple
 
 import numpy as np
@@ -20,7 +22,7 @@ def resistance_meander(
 ) -> Component:
     """Return meander to test resistance.
 
-    adapted from phidl.geometry
+    based on phidl.geometry
 
     Args:
         pad_size: Size of the two matched impedance pads (microns).
@@ -29,9 +31,7 @@ def resistance_meander(
         res_layer: resistance layer.
         pad_layer: pad layer.
         gnd_layer: ground layer.
-
     """
-
     x = pad_size[0]
     z = pad_size[1]
 
@@ -77,7 +77,7 @@ def resistance_meander(
     for i in range(num_rows):
         d = N.add_ref(T) if i != num_rows - 1 else N.add_ref(Row)
         if n % 2 == 0:
-            d.reflect(p1=(d.x, d.ymax), p2=(d.x, d.ymin))
+            d.mirror(p1=(d.x, d.ymax), p2=(d.x, d.ymin))
         d.movey(-(n - 1) * T.ysize)
         n += 1
     d = N.add_ref(Col).movex(-width)
@@ -86,9 +86,7 @@ def resistance_meander(
     # Creating pads
     P = Component()
     pad1 = rectangle(size=(x, z), layer=pad_layer)
-    pad2 = rectangle(size=(x + 5, z), layer=pad_layer)
-    gnd1 = offset(pad1, distance=-5, layer=gnd_layer)
-    gnd2 = offset(pad2, distance=-5, layer=gnd_layer)
+    gnd1 = gnd2 = offset(pad1, distance=-5, layer=gnd_layer)
     pad1_ref = P.add_ref(pad1)
     pad1_ref.movex(-x - width)
     pad2_ref = P.add_ref(pad1)
