@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import Tuple, Union
 
 import gdsfactory as gf
@@ -19,9 +21,9 @@ def seal_ring(
     with_east: bool = True,
     with_west: bool = True,
 ) -> gf.Component:
-    """Returns a continuous seal ring boundary at the chip/die
-    seal rings are useful to prevents cracks from spreading
-    you can connect it to ground
+    """Returns a continuous seal ring boundary at the chip/die.
+
+    Prevents cracks from spreading and shields when connected to ground.
 
     Args:
         bbox: to add seal ring around. You can pass Component.bbox.
@@ -32,9 +34,7 @@ def seal_ring(
         with_south: includes seal.
         with_east: includes seal.
         with_west: includes seal.
-
     """
-
     c = gf.Component()
     (xmin, ymin), (xmax, ymax) = bbox
 
