@@ -1,5 +1,4 @@
-r"""
-top view
+r"""Top view.
 
 .. code::
 
@@ -35,6 +34,8 @@ cross_section
 """
 
 
+from __future__ import annotations
+
 from functools import partial
 
 from gdsfactory.components.straight_heater_doped_rib import straight_heater_doped_rib
