@@ -1,4 +1,6 @@
 """Straight Doped PIN waveguide."""
+from __future__ import annotations
+
 from typing import Optional
 
 import gdsfactory as gf
@@ -25,7 +27,7 @@ def straight_pin_slot(
     taper: Optional[ComponentSpec] = taper_strip_to_ridge,
     **kwargs,
 ) -> Component:
-    """Returns a PIN straight waveguide with slotted via
+    """Returns a PIN straight waveguide with slotted via.
 
     https://doi.org/10.1364/OE.26.029983
 
@@ -45,9 +47,9 @@ def straight_pin_slot(
         via_stack_slab_bot: Optional, defaults to via_stack_slab.
         via_stack_slab_width: defaults to via_stack_width.
         via_stack_spacing: spacing between via_stacks.
+        via_stack_slab_spacing: spacing between via_stacks slabs.
         taper: optional taper.
         kwargs: cross_section settings.
-
     """
     c = Component()
     if taper:
