@@ -1,19 +1,20 @@
-"""
-                  __
-                _|  |_
-          __   | |  |_   _
-         |  |__| |__|    |
-        _|  |__          |dy
-         |__|  |  __     |
-               |_|  |_   |
-                 |  |_   -
-                 |__|
+"""Returns a switch_tree.
 
+          __
+        _|  |_
+  __   | |  |_   _
+ |  |__| |__|    |
+_|  |__          |dy
+ |__|  |  __     |
+       |_|  |_   |
+         |  |_   -
+         |__|
 
-           |<-dx->|
+   |<-dx->|
 
 """
 
+from __future__ import annotations
 
 import gdsfactory as gf
 from gdsfactory.components.mmi2x2 import mmi2x2
