@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import numpy as np
 
 import gdsfactory as gf
@@ -14,7 +16,7 @@ def taper_parabolic(
     npoints: int = 100,
     layer: LayerSpec = "WG",
 ) -> gf.Component:
-    """Returns a parabolic_taper
+    """Returns a parabolic_taper.
 
     Args:
         length: in um.
