@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import Optional, Tuple
 
 from numpy import floor
@@ -16,7 +18,7 @@ def via_stack_with_offset(
     offsets: Optional[Tuple[float, ...]] = None,
     port_orientation: float = 180,
 ) -> Component:
-    """Rectangular layer transition with offset between layers
+    """Rectangular layer transition with offset between layers.
 
     Args:
         layers: for each via.
