@@ -6,12 +6,15 @@ There are two types of functions:
 - containers: return a new component
 
 """
+from __future__ import annotations
+
 from functools import lru_cache, partial
 
 import numpy as np
 from omegaconf import OmegaConf
 from pydantic import validate_arguments
 
+from gdsfactory import ComponentReference
 from gdsfactory.cell import cell
 from gdsfactory.component import Component
 from gdsfactory.components.straight import straight
@@ -53,6 +56,7 @@ def add_text(
         text_offset: relative to component anchor. Defaults to center (cc).
         text_anchor: relative to component (ce cw nc ne nw sc se sw center cc).
         text_factory: function to add text labels.
+
     """
     from gdsfactory.pdk import get_component
 
@@ -86,9 +90,10 @@ def add_texts(
         text_offset: relative to component size info anchor. Defaults to center.
         text_anchor: relative to component (ce cw nc ne nw sc se sw center cc).
         text_factory: function to add text labels.
+
     """
     return [
-        add_text(component, text=f"{prefix}{i+index0}", **kwargs)
+        add_text(component, text=f"{prefix}{i + index0}", **kwargs)
         for i, component in enumerate(components)
     ]
 
@@ -106,6 +111,7 @@ def rotate(
         component: spec.
         angle: to rotate in degrees.
         recenter: recenter component after rotating.
+
     """
     from gdsfactory.pdk import get_component
 
@@ -144,6 +150,7 @@ def mirror(
         component: component spec.
         p1: first point to define mirror axis.
         p2: second point to define mirror axis.
+
     """
     from gdsfactory.pdk import get_component
 
@@ -181,10 +188,28 @@ def move(
     return component_new
 
 
+@cell
+def transformed(ref: ComponentReference):
+    """Returns flattened cell with reference transformations applied.
+
+    Args:
+        ref: the reference to flatten into a new cell.
+
+    """
+    c = Component()
+    c.add(ref)
+    c = c.flatten()
+    c.copy_child_info(ref.ref_cell)
+    c.add_ports(ref.ports)
+    c.info["transformed_cell"] = ref.ref_cell.name
+    return c
+
+
 def move_port_to_zero(component: Component, port_name: str = "o1"):
     """Return a container that contains a reference to the original component.
 
     The new component has port_name in (0, 0).
+
     """
     if port_name not in component.ports:
         raise ValueError(
@@ -206,7 +231,7 @@ def add_settings_label(
     settings: Optional[Strs] = None,
     ignore: Optional[Strs] = ("decorator",),
 ) -> Component:
-    """Add a settings label to a component.
+    """Add a settings label to a component. Use it as a decorator.
 
     Args:
         component: spec.
@@ -241,7 +266,6 @@ __all__ = (
     "update_info",
 )
 
-
 if __name__ == "__main__":
     import gdsfactory as gf
 
@@ -251,7 +275,10 @@ if __name__ == "__main__":
     )
     # c.show(show_ports=True)
 
-    cr = rotate(component=c)
+    # cr = rotate(component=c)
+    # cr.show()
+
+    cr = transformed(c.ref())
     cr.show()
 
     # cr = c.rotate()
