@@ -1,5 +1,7 @@
+from __future__ import annotations
+
 import gdsfactory as gf
-from gdsfactory.gdsdiff.gdsdiff import gdsdiff
+from gdsfactory.gdsdiff.gdsdiff import xor_polygons
 
 
 def test_differences() -> None:
@@ -12,8 +14,9 @@ def test_differences() -> None:
     )
     c1 = straight(length=2)
     c2 = straight(length=3)
-    c = gdsdiff(c1, c2)
-    assert c.references[-1].area() == 0.5
+    c = xor_polygons(c1, c2, hash_geometry=False)
+    area = c.area()
+    assert area == 0.5, area
 
 
 def test_no_differences() -> None:
@@ -26,14 +29,15 @@ def test_no_differences() -> None:
     )
     c1 = straight(length=2)
     c2 = straight(length=2)
-    c = gdsdiff(c1, c2)
-    assert c.references[-1].area() == 0
+    c = xor_polygons(c1, c2, hash_geometry=False)
+    area = c.area()
+    assert area == 0, area
 
 
 if __name__ == "__main__":
     # test_no_differences()
     # test_differences()
-    c1 = gf.components.straight(length=2)
-    c2 = gf.components.straight(length=2)
-    c = gdsdiff(c1, c2)
+    c1 = gf.components.mzi(length_x=3)
+    c2 = gf.components.mzi(length_x=2)
+    c = xor_polygons(c1, c2, hash_geometry=False)
     c.show(show_ports=True)
