@@ -1,12 +1,15 @@
+from __future__ import annotations
+
 from pathlib import Path
 from typing import Union
 
 
 def check_duplicated_cells(gdspath: Union[Path, str]):
-    """Reads cell and checks for duplicated cells
+    """Reads cell and checks for duplicated cells.
 
     Args:
         gdspath: path to GDS or Component
+
     """
     import klayout.db as pya
 
