@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import Tuple
 
 from gdsfactory.types import ComponentOrPath
@@ -15,8 +17,8 @@ def check_inclusion(
     min_projection: None = None,
     max_projection: None = None,
 ) -> int:
-    """reads layer from top cell and returns a the area that violates min inclusion
-    if 0 no area violates exclusion
+    """Reads layer from top cell and returns a the area that violates min \
+    inclusion if 0 no area violates exclusion.
 
     Args:
         gdspath: path to GDS.
@@ -29,6 +31,7 @@ def check_inclusion(
         metrics: Specify the metrics type.
         min_projection: lower threshold of the projected length of one edge onto another.
         max_projection: upper limit of the projected length of one edge onto another.
+
     """
     import klayout.db as pya
 
