@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from pathlib import Path
 from typing import Tuple, Union
 
@@ -10,13 +12,14 @@ def check_width(
     min_width: float = 0.150,
     dbu: float = 1e3,
 ) -> int:
-    """Reads layer from top cell and returns a number of edges violating min width
+    """Reads layer from top cell and returns a number of edges violating min width.
 
     Args:
         gdspath: path to GDS or Component.
         layer: tuple (int, int).
         min_width: in um.
         dbu: database units (1000 um/nm).
+
     """
     import klayout.db as pya
 
