@@ -1,18 +1,19 @@
-import inspect
+from __future__ import annotations
+
 from collections.abc import Iterable
-from inspect import getmembers
+from inspect import getmembers, signature
 
 from gdsfactory.types import Component, ComponentFactory, Dict
 
 
 def get_cells(modules, verbose: bool = False) -> Dict[str, ComponentFactory]:
-    """Returns Pcells (component functions) from a module or list of modules.
+    """Returns PCells (component functions) from a module or list of modules.
 
     Args:
         modules: module or iterable of modules.
         verbose: prints in case any errors occur.
-    """
 
+    """
     modules = modules if isinstance(modules, Iterable) else [modules]
 
     cells = {}
@@ -20,8 +21,10 @@ def get_cells(modules, verbose: bool = False) -> Dict[str, ComponentFactory]:
         for t in getmembers(module):
             if callable(t[1]) and t[0] != "partial":
                 try:
-                    r = inspect.signature(t[1]).return_annotation
-                    if r == Component:
+                    r = signature(t[1]).return_annotation
+                    if r == Component or (
+                        isinstance(r, str) and r.endswith("Component")
+                    ):
                         cells[t[0]] = t[1]
                 except ValueError:
                     if verbose:
