@@ -1,15 +1,35 @@
+"""Install Klayout and GIT plugins."""
+from __future__ import annotations
+
 import configparser
 import os
 import pathlib
 import shutil
 import subprocess
 import sys
-from pathlib import Path
+from typing import Optional
 
 
-def make_link(src, dest):
+def remove_path_or_dir(dest: pathlib.Path):
+    if dest.is_dir():
+        if dest.is_symlink():
+            os.unlink(dest)
+        else:
+            shutil.rmtree(dest)
+    else:
+        os.remove(dest)
+
+
+def make_link(src, dest, overwrite: bool = True) -> None:
+    dest = pathlib.Path(dest)
+    if dest.exists() and not overwrite:
+        print(f"{dest} already exists")
+        return
+    if dest.exists() or dest.is_symlink():
+        print(f"removing {dest} already installed")
+        remove_path_or_dir(dest)
     try:
-        os.symlink(src, dest)
+        os.symlink(src, dest, target_is_directory=True)
     except OSError as err:
         print("Could not create symlink!")
         print("     Error: ", err)
@@ -19,6 +39,9 @@ def make_link(src, dest):
             proc = subprocess.check_call(f"mklink /J {dest} {src}", shell=True)
             if proc != 0:
                 print("Could not create link!")
+    print("Symlink made:")
+    print(f"From: {src}")
+    print(f"To:   {dest}")
 
 
 def install_gdsdiff() -> None:
@@ -65,7 +88,7 @@ def write_git_config(git_config_path):
 
 
 def get_klayout_path() -> pathlib.Path:
-    """Returns klayout path."""
+    """Returns KLayout path."""
     klayout_folder = "KLayout" if sys.platform == "win32" else ".klayout"
     home = pathlib.Path.home()
     return home / klayout_folder
@@ -78,10 +101,7 @@ def copy(src: pathlib.Path, dest: pathlib.Path) -> None:
 
     if dest.exists() or dest.is_symlink():
         print(f"removing {dest} already installed")
-        if dest.is_dir():
-            shutil.rmtree(dest)
-        else:
-            os.remove(dest)
+        remove_path_or_dir(dest)
 
     if src.is_dir():
         shutil.copytree(src, dest)
@@ -90,26 +110,40 @@ def copy(src: pathlib.Path, dest: pathlib.Path) -> None:
     print(f"{src} copied to {dest}")
 
 
-def make_symlink(src: Path, dest: Path) -> None:
-    """Creates symbolic link from src to dest."""
-    if dest.exists():
-        os.remove(dest)
+def _install_to_klayout(
+    src: pathlib.Path, klayout_subdir_name: str, package_name: str
+) -> None:
+    """Install into KLayout technology.
+
+    Equivalent to using KLayout package manager.
+
+    """
+    klayout_folder = "KLayout" if sys.platform == "win32" else ".klayout"
+    subdir = pathlib.Path.home() / klayout_folder / klayout_subdir_name
+    dest = subdir / package_name
+    subdir.mkdir(exist_ok=True, parents=True)
     make_link(src, dest)
-    print("Symlink made:")
-    print(f"From: {src}")
-    print(f"To:   {dest}")
 
 
 def install_klayout_package() -> None:
-    """Install klayout package. Equivalent to using klayout package manager."""
-    klayout_folder = "KLayout" if sys.platform == "win32" else ".klayout"
+    """Install gdsfactory KLayout package.
+
+    Equivalent to using KLayout package manager.
+
+    """
     cwd = pathlib.Path(__file__).resolve().parent
-    home = pathlib.Path.home()
-    src = cwd / "klayout"
-    dest = home / klayout_folder / "salt" / "gdsfactory"
-    salt = home / klayout_folder / "salt"
-    salt.mkdir(exist_ok=True, parents=True)
-    make_symlink(src, dest)
+    _install_to_klayout(
+        src=cwd / "klayout", klayout_subdir_name="salt", package_name="gdsfactory"
+    )
+
+
+def install_klayout_technology(tech_dir: pathlib.Path, tech_name: Optional[str] = None):
+    """Install technology to KLayout."""
+    _install_to_klayout(
+        src=tech_dir,
+        klayout_subdir_name="tech",
+        package_name=tech_name or tech_dir.name,
+    )
 
 
 if __name__ == "__main__":
