@@ -1,8 +1,13 @@
-"""Update GDS view in Klayout dynamically.
-Requires the Klayout plugin installed in Klayout.
-This happens when you run `pf install`.
+"""Stream GDS to Klayout.
+
+You can install gdsfactory KLayout integration:
+
+- run `gf tool install`
+- install the Klayout plugin through klayout package manager.
 """
 
+from __future__ import annotations
+
 import json
 import os
 import socket
