@@ -1,11 +1,11 @@
+from __future__ import annotations
+
 from gdsfactory.read.from_dphox import from_dphox
 from gdsfactory.read.from_gdspaths import from_gdsdir, from_gdspaths
 from gdsfactory.read.from_np import from_np
-from gdsfactory.read.from_phidl import from_phidl
-from gdsfactory.read.from_picwriter import from_picwriter
+from gdsfactory.read.from_phidl import from_gdstk, from_phidl
 from gdsfactory.read.from_yaml import from_yaml
 from gdsfactory.read.import_gds import import_gds
-from gdsfactory.read.import_oas import import_oas
 
 __all__ = [
     "from_dphox",
@@ -13,8 +13,7 @@ __all__ = [
     "from_gdspaths",
     "from_np",
     "from_phidl",
-    "from_picwriter",
     "from_yaml",
+    "from_gdstk",
     "import_gds",
-    "import_oas",
 ]
