@@ -1,4 +1,6 @@
 """Read component from a numpy.ndarray."""
+from __future__ import annotations
+
 from typing import Tuple
 
 import numpy as np
@@ -11,7 +13,9 @@ def compute_area_signed(pr) -> float:
     """Return the signed area enclosed by a ring using the linear time.
 
     algorithm at http://www.cgafaq.info/wiki/Polygon_Area. A value >= 0
-    indicates a counter-clockwise oriented ring."""
+    indicates a counter-clockwise oriented ring.
+
+    """
     xs, ys = map(list, zip(*pr))
     xs.append(xs[1])
     ys.append(ys[1])
