@@ -1,5 +1,7 @@
 """Functions to create routes between components."""
 
+from __future__ import annotations
+
 from gdsfactory.routing import sort_ports, utils
 from gdsfactory.routing.add_electrical_pads_shortest import add_electrical_pads_shortest
 from gdsfactory.routing.add_electrical_pads_top import add_electrical_pads_top
@@ -28,11 +30,14 @@ from gdsfactory.routing.get_bundle_sbend import get_bundle_sbend
 from gdsfactory.routing.get_route import (
     get_route,
     get_route_electrical,
+    get_route_electrical_m2,
     get_route_electrical_multilayer,
     get_route_from_waypoints,
     get_route_from_waypoints_electrical,
+    get_route_from_waypoints_electrical_m2,
     get_route_from_waypoints_electrical_multilayer,
 )
+from gdsfactory.routing.get_route_astar import get_route_astar
 from gdsfactory.routing.get_route_from_steps import (
     get_route_from_steps,
     get_route_from_steps_electrical,
@@ -63,7 +68,9 @@ __all__ = [
     "get_bundle_from_waypoints_electrical",
     "get_bundle_from_waypoints_electrical_multilayer",
     "get_route",
+    "get_route_astar",
     "get_route_electrical",
+    "get_route_electrical_m2",
     "get_route_electrical_multilayer",
     "get_routes_bend180",
     "get_routes_straight",
@@ -71,6 +78,7 @@ __all__ = [
     "get_bundle_sbend",
     "get_route_from_waypoints",
     "get_route_from_waypoints_electrical",
+    "get_route_from_waypoints_electrical_m2",
     "get_route_from_waypoints_electrical_multilayer",
     "get_route_from_steps",
     "get_route_from_steps_electrical",
