@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import warnings
 from typing import Callable, Optional, Tuple
 
@@ -91,6 +93,10 @@ def add_fiber_array(
         gc = grating_coupler
     gc = gf.get_component(gc)
 
+    if gc_port_name not in gc.ports:
+        gc_ports = list(gc.ports.keys())
+        raise ValueError(f"gc_port_name = {gc_port_name!r} not in {gc_ports}")
+
     orientation = gc.ports[gc_port_name].orientation
 
     grating_coupler = (
@@ -162,6 +168,7 @@ def add_fiber_array(
                 component_new.add_port(f"{port.name}_{i}{j}", port=port)
 
     component_new.copy_child_info(component)
+    component_new.info["grating_coupler"] = gc.info
     return component_new
 
 
@@ -207,7 +214,8 @@ if __name__ == "__main__":
     # c = gf.components.ring_single()
     # c = gf.components.straight_heater_metal()
     # c = gf.components.spiral(direction="NORTH")
-    c = gf.components.mzi()
+
+    c = gf.components.bend_euler(info=dict(doe="bends"))
     cc = add_fiber_array(
         component=c,
         # optical_routing_type=0,
@@ -222,5 +230,6 @@ if __name__ == "__main__":
         # layer=(2, 0),
         gc_port_labels=["loop_in", "in", "out", "loop_out"],
         cross_section=strip,
+        info=dict(a=1),
     )
     cc.show(show_ports=True)
