@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import Dict, List, Optional, Union
 
 import numpy as np
@@ -10,6 +12,7 @@ from gdsfactory.components.via_corner import via_corner
 from gdsfactory.components.wire import wire_corner
 from gdsfactory.port import Port
 from gdsfactory.routing.get_bundle_from_waypoints import get_bundle_from_waypoints
+from gdsfactory.routing.manhattan import _is_horizontal, _is_vertical
 from gdsfactory.routing.sort_ports import sort_ports as sort_ports_function
 from gdsfactory.types import (
     ComponentSpec,
@@ -32,7 +35,7 @@ def get_bundle_from_steps(
     path_length_match_loops: int = None,
     path_length_match_extra_length: float = 0.0,
     path_length_match_modify_segment_i: int = -2,
-    **kwargs
+    **kwargs,
 ) -> List[Route]:
     """Returns a list of routes formed by the given waypoints steps.
 
@@ -114,11 +117,14 @@ def get_bundle_from_steps(
     port2 = ports2[0]
     x2, y2 = port2.center
     orientation = port2.orientation
-
-    # if orientation is None:
-    #     waypoints += [(x2, y2)]
-
-    if int(orientation) in {0, 180}:
+    if orientation is None:
+        p1 = waypoints[-2]
+        p0 = waypoints[-1]
+        if _is_vertical(p0, p1):
+            waypoints += [(y2, y)]
+        elif _is_horizontal(p0, p1):
+            waypoints += [(x, x2)]
+    elif int(orientation) in {0, 180}:
         waypoints += [(x, y2)]
     elif int(orientation) in {90, 270}:
         waypoints += [(x2, y)]
@@ -159,7 +165,7 @@ def get_bundle_from_steps(
 
 
 get_bundle_from_steps_electrical = gf.partial(
-    get_bundle_from_steps, bend=wire_corner, cross_section=gf.cross_section.metal3
+    get_bundle_from_steps, bend=wire_corner, cross_section="metal_routing"
 )
 
 get_bundle_from_steps_electrical_multilayer = gf.partial(
@@ -167,7 +173,7 @@ get_bundle_from_steps_electrical_multilayer = gf.partial(
     bend=via_corner,
     cross_section=[
         (gf.cross_section.metal2, (90, 270)),
-        (gf.cross_section.metal3, (0, 180)),
+        ("metal_routing", (0, 180)),
     ],
 )
 
