@@ -1,9 +1,12 @@
+from __future__ import annotations
+
 from typing import Any, Callable, List, Optional, Tuple, Union
 
 import numpy as np
 from numpy import float64, ndarray
 
 from gdsfactory.components.bend_euler import bend_euler
+from gdsfactory.components.straight import straight as straight_function
 from gdsfactory.geometry.functions import remove_identicals
 from gdsfactory.port import Port
 from gdsfactory.routing.get_route import get_route_from_waypoints
@@ -95,8 +98,7 @@ def get_bundle_udirect(
                                   |
                            X------/
     """
-    if "straight" in kwargs.keys():
-        _ = kwargs.pop("straight")
+    straight = kwargs.pop("straight", straight_function)
     routes = _get_bundle_udirect_waypoints(
         ports1,
         ports2,
@@ -119,7 +121,9 @@ def get_bundle_udirect(
             **kwargs,
         )
 
-    return [route_filter(route, bend=bend, **kwargs) for route in routes]
+    return [
+        route_filter(route, bend=bend, straight=straight, **kwargs) for route in routes
+    ]
 
 
 def _get_bundle_udirect_waypoints(
@@ -319,7 +323,6 @@ def get_bundle_uindirect(
         '''
 
     """
-
     routes = _get_bundle_uindirect_waypoints(
         ports1,
         ports2,
@@ -373,11 +376,7 @@ def _get_bundle_uindirect_waypoints(
     ys_end = [p.y for p in ports2]
 
     # Compute the bundle axis
-    if ports1[0].orientation in [0, 180]:
-        axis = "X"
-    else:
-        axis = "Y"
-
+    axis = "X" if ports1[0].orientation in [0, 180] else "Y"
     # Split start ports in two groups:
     #    - the ones on the south/west of end ports (depending on bundle axis)
     #    - the ones on the north/east of end ports (depending on bundle axis)
@@ -388,10 +387,11 @@ def _get_bundle_uindirect_waypoints(
         group2 = [p for p in ports1 if p.y > y_cut]
 
         if ports1[0].orientation == 0 and ports2[0].orientation == 180:
-            """
-                 X->
+            """X->
+
             <-D
                  X->
+
             """
             # To go back to a U bundle
             group1_route_directives = ["north", "west"]
@@ -462,11 +462,11 @@ def _get_bundle_uindirect_waypoints(
     def add_connections(conns) -> None:
         """Adds connections.
 
-        Ensures that each section in a batch of connection.
-        is added to the correct route. Also we don't know in which order the
-        routes are given (from beginning to end or vice versa)
-        """
+        Ensures that each section in a batch of connection. is added to
+        the correct route. Also we don't know in which order the routes
+        are given (from beginning to end or vice versa)
 
+        """
         end_prev_conns = [(k, v[-1][-1]) for k, v in dict_connections.items()]
         for c in conns:
             p = c[0]
