@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import Callable, List, Optional, Tuple, Union
 
 import gdsfactory as gf
@@ -7,7 +9,6 @@ from gdsfactory.components.bend_euler import bend_euler
 from gdsfactory.components.grating_coupler_elliptical_trenches import grating_coupler_te
 from gdsfactory.components.straight import straight as straight_function
 from gdsfactory.components.taper import taper as taper_function
-from gdsfactory.config import TECH
 from gdsfactory.cross_section import strip
 from gdsfactory.port import Port, select_ports_optical
 from gdsfactory.routing.get_bundle import get_bundle, get_min_spacing
@@ -27,7 +28,7 @@ from gdsfactory.types import (
 
 def route_fiber_array(
     component: Component,
-    fiber_spacing: float = TECH.fiber_array_spacing,
+    fiber_spacing: Union[str, float] = "fiber_array_spacing",
     grating_coupler: ComponentSpecOrList = grating_coupler_te,
     bend: ComponentSpec = bend_euler,
     straight: ComponentSpec = straight_function,
@@ -61,16 +62,15 @@ def route_fiber_array(
 ) -> Tuple[
     List[Union[ComponentReference, Label]], List[List[ComponentReference]], List[Port]
 ]:
-    """Returns component I/O elements for adding grating couplers with a fiber array
-    Many components are fine with the defaults.
+    """Returns component I/O elements for adding grating couplers with a fiber array Many components are fine with the defaults.
 
     Args:
         component: component spec to connect to.
-        fiber_spacing: the wanted spacing between the optical I/O.
+        fiber_spacing: spacing between the optical fibers.
         grating_coupler: grating coupler instance, function or list of functions.
         bend: for bends.
         straight: straight.
-        fanout_length: target distance between gratings and the southest component port.
+        fanout_length: target distance between gratings and the southmost component port.
             If None, automatically calculated.
         max_y0_optical: Maximum y coordinate at which the intermediate optical ports can be set.
             Usually fine to leave at None.
@@ -119,8 +119,9 @@ def route_fiber_array(
         elements: list of references.
         io_grating_lines: grating lines.
         list of ports: to connect to.
-    """
 
+    """
+    fiber_spacing = gf.get_constant(fiber_spacing)
     cross_section = x = gf.get_cross_section(cross_section, **kwargs)
     radius = x.radius
 
@@ -154,12 +155,10 @@ def route_fiber_array(
         grating_coupler = gf.call_if_func(grating_coupler)
         grating_couplers = [grating_coupler] * N
 
-    assert (
-        gc_port_name in grating_coupler.ports
-    ), f"{gc_port_name} not in {list(grating_coupler.ports.keys())}"
-
     if gc_port_name not in grating_coupler.ports:
-        raise ValueError(f"{gc_port_name} not in {list(grating_coupler.ports.keys())}")
+        raise ValueError(
+            f"{gc_port_name!r} not in {list(grating_coupler.ports.keys())}"
+        )
 
     # Now:
     # - grating_coupler is a single grating coupler
@@ -193,12 +192,9 @@ def route_fiber_array(
         or (component.xsize > fiber_spacing)
     )
     if optical_routing_type is None:
-        if not is_big_component:
-            optical_routing_type = 0
-        else:
-            optical_routing_type = 1
-
+        optical_routing_type = 1 if is_big_component else 0
     # choose the default length if the default fanout distance is not set
+
     def has_p(side):
         return len(direction_ports[side]) > 0
 
@@ -210,9 +206,10 @@ def route_fiber_array(
 
     is_one_sided_horizontal = False
     for side1, side2 in [("E", "W"), ("W", "E")]:
-        if len(direction_ports[side1]) >= 2:
-            if all([len(direction_ports[side]) == 0 for side in ["N", "S", side2]]):
-                is_one_sided_horizontal = True
+        if len(direction_ports[side1]) >= 2 and all(
+            len(direction_ports[side]) == 0 for side in ["N", "S", side2]
+        ):
+            is_one_sided_horizontal = True
 
     # Compute fanout length if not specified
     if fanout_length is None:
@@ -250,7 +247,7 @@ def route_fiber_array(
 
     ports = []
     north_ports = direction_ports["N"]
-    north_start = north_ports[0 : len(north_ports) // 2]
+    north_start = north_ports[: len(north_ports) // 2]
     north_finish = north_ports[len(north_ports) // 2 :]
 
     west_ports = direction_ports["W"]
@@ -291,13 +288,13 @@ def route_fiber_array(
         ports += [grating.ports[gc_port_name] for grating in io_gratings]
 
     if optical_routing_type == 0:
-        """
-        Basic optical routing, typically fine for small components
-        No heuristic to avoid collisions between connectors.
+        """Basic optical routing, typically fine for small components No
+        heuristic to avoid collisions between connectors.
+
+        If specified ports to connect in a specific order (i.e if
+        connected_port_names is not None and not empty) then grab these
+        ports
 
-        If specified ports to connect in a specific order
-        (i.e if connected_port_names is not None and not empty)
-        then grab these ports
         """
         if connected_port_names:
             ordered_ports = [component.ports[i] for i in connected_port_names]
@@ -340,11 +337,12 @@ def route_fiber_array(
         elements.extend(elems)
 
         if force_manhattan:
-            """
-            1) find the min x_distance between each grating port and
-            each component port.
-            2) If abs(min distance) < 2* bend radius
-                then offset io_gratings by -min_distance
+            """1) find the min x_distance between each grating port and each
+            component port.
+
+            2) If abs(min distance) < 2* bend radius     then offset
+            io_gratings by -min_distance
+
             """
             min_dist = 2 * dy + 10.0
             min_dist_threshold = 2 * dy + 1.0
@@ -368,7 +366,7 @@ def route_fiber_array(
         if min_y > delta_y:
             for io_gratings in io_gratings_lines:
                 for gr in io_gratings:
-                    gr.translate(0, delta_y - min_y)
+                    gr.origin = (gr.origin[0], gr.origin[1] + delta_y - min_y)
 
         # If we add align ports, we need enough space for the bends
         end_straight_offset = straight_separation + 5 if with_loopback else x.min_length
