@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import List, Tuple
 
 from gdsfactory.port import Port
@@ -29,6 +31,7 @@ def sort_ports(ports1: List[Port], ports2: List[Port]) -> Tuple[List[Port], List
     Args:
         ports1:
         ports2:
+
     """
     if len(ports1) != len(ports2):
         raise ValueError(f"ports1={len(ports1)} and ports2={len(ports2)} must be equal")
@@ -65,7 +68,6 @@ def sort_ports(ports1: List[Port], ports2: List[Port]) -> Tuple[List[Port], List
 if __name__ == "__main__":
     import gdsfactory as gf
     from gdsfactory.cell import cell
-    from gdsfactory.port import Port
 
     @cell
     def demo_connect_corner(N=6, config="A"):
