@@ -1,8 +1,12 @@
 """When you create components you have to make sure they have unique names.
 
-the cell decorator gives unique names to components that depend on their parameters
+the cell decorator gives unique names to components that depend on their
+parameters
+
 """
 
+from __future__ import annotations
+
 import gdsfactory as gf
 
 
