@@ -1,4 +1,4 @@
-""" based on phidl tutorial
+"""based on phidl tutorial.
 
 # Connecting devices with connect()
 
@@ -12,6 +12,8 @@ or with a negative number if you want to separate the ports.
 """
 
 
+from __future__ import annotations
+
 import gdsfactory as gf
 
 if __name__ == "__main__":
