@@ -1,4 +1,4 @@
-"""Lets create a crossing component with two references to other components (crossing_arm)
+"""Lets create a crossing component with two references to other components (crossing_arm).
 
 - add references to a component (one of the arm references rotated)
 - add ports from the child references into the parent cell
@@ -6,6 +6,8 @@
 
 """
 
+from __future__ import annotations
+
 import gdsfactory as gf
 from gdsfactory.component import Component
 from gdsfactory.types import Layer
@@ -21,7 +23,7 @@ def test_crossing_arm(
     layer_wg: Layer = (1, 0),
     layer_slab: Layer = (2, 0),
 ) -> Component:
-    """crossing arm"""
+    """Crossing arm."""
     c = gf.Component()
     c << gf.components.ellipse(radii=(r1, r2), layer=layer_slab)
 
