@@ -1,10 +1,7 @@
-"""# Components.
-You can adapt some component functions from the `gdsfactory.components` module.
-Each function there returns a Component object
+"""# Components. You can adapt some component functions from the `gdsfactory.components` module. Each function there returns a Component object. Here are two equivalent functions."""
 
-Here are two equivalent functions
-"""
 
+from __future__ import annotations
 
 import gdsfactory as gf
 
