@@ -1,5 +1,6 @@
-"""You can also use the fiber array routing functions for connecting to pads.
-"""
+"""You can also use the fiber array routing functions for connecting to pads."""
+
+from __future__ import annotations
 
 import gdsfactory as gf
 from gdsfactory.samples.big_device import big_device
