@@ -1,9 +1,11 @@
-"""
-Lets pack a doe and export it with metadata
+"""Lets pack a doe and export it with metadata.
+
 by Jan-David Fischbach
 email: jan-david.fischbach@blacksemicon.de
 date: 26.06.22
 """
+from __future__ import annotations
+
 import gdsfactory as gf
 
 if __name__ == "__main__":
