@@ -1,6 +1,6 @@
-"""
-Small demonstration of the slot cross_section utilising add_center_section=False
-"""
+"""Small demonstration of the slot cross_section utilizing add_center_section=False."""
+
+from __future__ import annotations
 
 import gdsfactory as gf
 
