@@ -2,10 +2,12 @@
 
 Exercise1. increase the number of elements of the phase array.
 
-Exercise2. Make a Pcell.
+Exercise2. Make a PCell.
 
 """
 
+from __future__ import annotations
+
 import gdsfactory as gf
 
 
