@@ -1,5 +1,4 @@
-"""
-Adapted from https://github.com/simbilod/option
+"""Adapted from https://github.com/simbilod/option.
 
 SMF specs from photonics.byu.edu/FiberOpticConnectors.parts/images/smf28.pdf
 
@@ -7,8 +6,11 @@ MFD:
 
 - 10.4 for Cband
 - 9.2 for Oband
+
 """
 
+from __future__ import annotations
+
 import hashlib
 from typing import Any, Dict, Optional
 
@@ -33,7 +35,6 @@ def get_simulation_grating_fiber(
     n_periods: int = 30,
     widths: Optional[Floats] = None,
     gaps: Optional[Floats] = None,
-    slab_thickness: float = 150 * nm,
     fiber_angle_deg: float = 20.0,
     fiber_xposition: float = 1.0,
     fiber_core_diameter: float = 10.4,
@@ -48,6 +49,7 @@ def get_simulation_grating_fiber(
     substrate_thickness: float = 1.0,
     box_thickness: float = 2.0,
     wg_thickness: float = 220 * nm,
+    slab_thickness: float = 150 * nm,
     top_clad_thickness: float = 2.0,
     air_gap_thickness: float = 1.0,
     fiber_thickness: float = 2.0,
@@ -55,6 +57,7 @@ def get_simulation_grating_fiber(
     wavelength_start: float = 1.4,
     wavelength_stop: float = 1.7,
     wavelength_points: int = 150,
+    decay_by: float = 1e-3,
     eps_averaging: bool = False,
     fiber_port_y_offset_from_air: float = 1,
     waveguide_port_x_offset_from_grating_start: float = 10,
@@ -62,11 +65,12 @@ def get_simulation_grating_fiber(
     xmargin: float = 10.0,
 ) -> Dict[str, Any]:
     r"""Returns simulation results from grating coupler with fiber.
+
     na**2 = ncore**2 - nclad**2
     ncore = sqrt(na**2 + ncore**2)
 
     Args:
-        period: fiber grating period.
+        period: fiber grating period in um.
         fill_factor: fraction of the grating period filled with the grating material.
         n_periods: number of periods.
         widths: Optional list of widths. Overrides period, fill_factor, n_periods.
@@ -76,8 +80,8 @@ def get_simulation_grating_fiber(
         fiber_core_diameter: fiber diameter.
         fiber_numerical_aperture: NA.
         fiber_nclad: fiber cladding index.
-        fiber_ncore: fiber core index.
         nwg: waveguide index.
+        nslab: slab refractive index.
         nclad: top cladding index.
         nbox: box index bottom.
         nsubstrate: index substrate.
@@ -85,6 +89,7 @@ def get_simulation_grating_fiber(
         substrate_thickness: substrate_thickness (um).
         box_thickness: thickness for bottom cladding (um).
         wg_thickness: wg_thickness (um).
+        slab_thickness: slab thickness (um). etch_depth=wg_thickness-slab_thickness.
         top_clad_thickness: thickness of the top cladding.
         air_gap_thickness: air gap thickness.
         fiber_thickness: fiber_thickness.
@@ -160,6 +165,7 @@ def get_simulation_grating_fiber(
         wavelength_start=wavelength_start,
         wavelength_stop=wavelength_stop,
         wavelength_points=wavelength_points,
+        decay_by=decay_by,
         eps_averaging=eps_averaging,
         fiber_port_y_offset_from_air=fiber_port_y_offset_from_air,
         waveguide_port_x_offset_from_grating_start=waveguide_port_x_offset_from_grating_start,
@@ -457,9 +463,8 @@ def get_port_1D_eigenmode(
     band_num: int = 1,
     fiber_angle_deg: float = 15.0,
 ):
-    """
+    """Args are the following.
 
-    Args:
         sim_dict: simulation dict
         band_num: band number to solve for
 
@@ -531,9 +536,7 @@ def get_port_1D_eigenmode(
 
 
 def plot(sim, eps_parameters=None) -> None:
-    """
-    sim: simulation object
-    """
+    """sim: simulation object."""
     sim.plot2D(eps_parameters=eps_parameters)
     # plt.colorbar()
 
