@@ -1,8 +1,12 @@
-"""gdsfactory tidy3d plugin
+"""gdsfactory tidy3d plugin.
+
+[tidy3D is a fast GPU based commercial FDTD
+solver](https://simulation.cloud/)
 
-[tidy3D is a fast GPU based commercial FDTD solver](https://simulation.cloud/)
 """
 
+from __future__ import annotations
+
 import tidy3d as td
 
 from gdsfactory.config import logger
