@@ -1,4 +1,6 @@
-"""gdsfactory tidy3d plugin utils"""
+"""gdsfactory tidy3d plugin utils."""
+
+from __future__ import annotations
 
 from functools import partial
 from typing import Optional
@@ -20,8 +22,8 @@ def delete_tasks(status: str = "error") -> None:
 
     Args:
         status: error, diverged, preprocess
-    """
 
+    """
     for task in web.get_tasks():
         # print(task["status"], task["task_name"], task["task_id"])
         if task["status"] == status:
