@@ -1,4 +1,5 @@
 """gdsfactory simphony circuit simulation plugin."""
+from __future__ import annotations
 
 try:
     from simphony.tools import freq2wl, wl2freq
@@ -16,12 +17,10 @@ from gdsfactory.simulation.simphony import components
 from gdsfactory.simulation.simphony.add_gc import add_gc
 from gdsfactory.simulation.simphony.circuit import component_to_circuit
 from gdsfactory.simulation.simphony.components import model_factory
-from gdsfactory.simulation.simphony.model_from_gdsfactory import model_from_gdsfactory
-from gdsfactory.simulation.simphony.model_from_sparameters import (
-    model_from_csv,
-    model_from_filepath,
-    model_from_sparameters,
+from gdsfactory.simulation.simphony.model_from_gdsfactory import (
+    GDSFactorySimphonyWrapper,
 )
+from gdsfactory.simulation.simphony.model_from_sparameters import SimphonyFromFile
 from gdsfactory.simulation.simphony.plot_circuit import plot_circuit
 from gdsfactory.simulation.simphony.plot_circuit_montecarlo import (
     plot_circuit_montecarlo,
@@ -33,10 +32,8 @@ __all__ = [
     "component_to_circuit",
     "components",
     "model_factory",
-    "model_from_gdsfactory",
-    "model_from_sparameters",
-    "model_from_csv",
-    "model_from_filepath",
+    "GDSFactorySimphonyWrapper",
+    "SimphonyFromFile",
     "plot_model",
     "plot_circuit",
     "plot_circuit_montecarlo",
