@@ -1,5 +1,9 @@
+from __future__ import annotations
+
 import gdsfactory as gf
-from gdsfactory.simulation.simphony.model_from_gdsfactory import model_from_gdsfactory
+from gdsfactory.simulation.simphony.model_from_gdsfactory import (
+    GDSFactorySimphonyWrapper,
+)
 
 
 def coupler_fdtd(c=gf.c.coupler, width=0.5, length=20, gap=0.224):
@@ -25,7 +29,7 @@ def coupler_fdtd(c=gf.c.coupler, width=0.5, length=20, gap=0.224):
     """
     if callable(c):
         c = c(width=width, length=length, gap=gap)
-    return model_from_gdsfactory(c)
+    return GDSFactorySimphonyWrapper(component=c)
 
 
 if __name__ == "__main__":
@@ -36,7 +40,7 @@ if __name__ == "__main__":
     f = 3e8 / wav
     c = gf.c.coupler(length=20, gap=0.224)
     m = coupler_fdtd(c=c)
-    s = m.s_parameters(freq=f)
+    s = m.s_parameters(freqs=f)
 
     plt.plot(wav, np.abs(s[:, 1] ** 2))
     print(m.pins)
