@@ -1,5 +1,7 @@
+from __future__ import annotations
+
 from gdsfactory.config import sparameters_path
-from gdsfactory.simulation.simphony.model_from_sparameters import model_from_filepath
+from gdsfactory.simulation.simphony.model_from_sparameters import SimphonyFromFile
 
 
 def gc1550te(filepath=sparameters_path / "gc2dte" / "gc1550.dat", numports=2):
@@ -13,8 +15,9 @@ def gc1550te(filepath=sparameters_path / "gc2dte" / "gc1550.dat", numports=2):
 
         c = gc.gc1550te()
         gs.plot_model(c)
+
     """
-    return model_from_filepath(filepath=filepath, numports=numports)
+    return SimphonyFromFile(numports=numports).model_from_filepath(filepath=filepath)
 
 
 if __name__ == "__main__":
@@ -24,7 +27,7 @@ if __name__ == "__main__":
     wav = np.linspace(1520, 1570, 1024) * 1e-9
     f = 3e8 / wav
     c = gc1550te()
-    s = c.s_parameters(freq=f)
+    s = c.s_parameters(freqs=f)
 
     plt.plot(wav, np.abs(s[:, 1] ** 2))
     print(c.pins)
