@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import gdsfactory as gf
 from gdsfactory.component import Component
 
@@ -18,7 +20,7 @@ connections:
 
 
 def test_component_from_yaml_bezier() -> Component:
-    """bezier does not have cell"""
+    """bezier does not have cell."""
     c = gf.read.from_yaml(yaml)
     assert c.name == "test_bezier_03405c97", c.name
     assert len(c.get_dependencies()) == 2, len(c.get_dependencies())
