@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import gdsfactory as gf
 
 padding_example0 = """
@@ -37,6 +39,6 @@ instances:
 
 
 if __name__ == "__main__":
-    """TODO, fix this"""
+    """TODO, fix this."""
     c = gf.read.from_yaml(padding_example1)
     c.show(show_ports=True)
