@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import toolz
 
 import gdsfactory as gf
@@ -18,7 +20,7 @@ straigth_extended3 = toolz.compose(
 
 
 def test_compose1() -> None:
-    """Ensures the first level of composed function gets a unique name"""
+    """Ensures the first level of composed function gets a unique name."""
     extend_ports1 = gf.partial(gf.components.extend_ports, length=1)
     straigth_extended500 = gf.compose(
         extend_ports1, gf.partial(gf.components.straight, width=0.5)
