@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from pytest_regressions.data_regression import DataRegressionFixture
 
 import gdsfactory as gf
@@ -7,7 +9,7 @@ from gdsfactory.component import Component
 def demo_get_bundle_sbend_routing(
     data_regression: DataRegressionFixture, check: bool = True
 ) -> Component:
-    """FIXME"""
+    """FIXME."""
 
     lengths = {}
 
