@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import pytest
 
 import gdsfactory as gf
@@ -5,7 +7,7 @@ from gdsfactory.routing.manhattan import RouteWarning
 
 
 def test_route_error():
-    """Ensures that an impossible route raises value Error"""
+    """Ensures that an impossible route raises RouteWarning."""
     c = gf.Component("test_route_error")
     w = gf.components.straight()
     left = c << w
@@ -27,6 +29,7 @@ def test_route_error():
             ],
         )
         c.add(route.references)
+        c.add(route.labels)
     return c
 
 
