@@ -1,8 +1,10 @@
+from __future__ import annotations
+
 import gdsfactory as gf
 
 
 def test_route_error2():
-    """Ensures that an impossible route raises value Error"""
+    """Impossible route."""
     c = gf.Component("pads_route_from_steps")
     pt = c << gf.components.pad_array(orientation=270, columns=3)
     pb = c << gf.components.pad_array(orientation=90, columns=3)
@@ -13,10 +15,11 @@ def test_route_error2():
         steps=[
             {"y": 100},
         ],
-        cross_section=gf.cross_section.metal3,
+        cross_section="metal_routing",
         bend=gf.components.wire_corner,
     )
     c.add(route.references)
+    c.add(route.labels)
     return c
 
 
