@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import pytest
 
 import gdsfactory as gf
@@ -5,7 +7,7 @@ from gdsfactory.routing.manhattan import RouteWarning
 
 
 def test_route_error_bundle():
-    """Ensures that an impossible route raises value Error"""
+    """Ensures that an impossible route raises a RouteWarning."""
     c = gf.Component("get_route_from_steps_sample")
 
     w = gf.components.array(
