@@ -1,7 +1,12 @@
-"""FIXME. Tests are failing for python3.7
+"""FIXME.
+
+Tests are failing for python3.7
+
 """
 
 
+from __future__ import annotations
+
 import gdsfactory as gf
 from gdsfactory.component import hash_file
 
@@ -22,7 +27,7 @@ def _test_hash_array_file() -> None:
     c.add_array(wg)
     gdspath = c.write_gds()
     h = hash_file(gdspath)
-    href = "d8cd464778b3f52c33454af5d7335415"
+    href = "ed41db2253d80bb337510965bec6e422"
     assert h == href, f"href = {h!r}"
 
 
@@ -31,11 +36,11 @@ def _test_hash_file() -> None:
     c = gf.components.straight()
     gdspath = c.write_gds()
     h = hash_file(gdspath)
-    href = "d8cd464778b3f52c33454af5d7335415"
+    href = "120dd914e80c9a1f5bb30b8743e3f836"
     assert h == href, f"href = {h!r}"
 
 
 if __name__ == "__main__":
     # test_hash_geometry()
-    # _test_hash_file()
-    _test_hash_array_file()
+    _test_hash_file()
+    # _test_hash_array_file()
