@@ -1,11 +1,12 @@
-""" ensures gdslibrary exists
-"""
+"""ensures gdslibrary exists."""
+
+from __future__ import annotations
 
 import gdsfactory as gf
 
 
 def test_gdslib_exists() -> None:
-    assert gf.CONFIG["gdslib"].exists()
+    assert gf.PATH.gdslib.exists()
 
 
 if __name__ == "__main__":
