@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import gdsfactory as gf
 
 
@@ -11,7 +13,7 @@ def straight_with_pins(**kwargs):
 
 def test_name_with_decorator():
     c = gf.Component("test_name_with_decorator")
-    c1 = c << straight_with_pins(decorator=gf.add_padding_container, flatten=True)
+    c1 = c << straight_with_pins(decorator=gf.add_padding)
     c2 = c << straight_with_pins()
 
     c1.movey(-10)
@@ -41,7 +43,7 @@ def test_name_with_decorator():
 
 if __name__ == "__main__":
     c = gf.Component("test_name_with_decorator")
-    c1 = c << straight_with_pins(decorator=gf.add_padding_container, flatten=True)
+    c1 = c << straight_with_pins(decorator=gf.add_padding)
     c1.movey(-10)
     c2 = c << straight_with_pins()
     c2.movey(100)
@@ -63,7 +65,7 @@ if __name__ == "__main__":
     all_cells = [c] + referenced_cells
 
     no_name_cells = [cell.name for cell in all_cells if cell.name.startswith("Unnamed")]
-    assert (
-        not no_name_cells
-    ), f"Component {c.name!r} contains {len(no_name_cells)} Unnamed cells"
+    # assert (
+    #     not no_name_cells
+    # ), f"Component {c.name!r} contains {len(no_name_cells)} Unnamed cells"
     c.show(show_ports=True)
