@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from gdsfactory.port import csv2port
 
 
@@ -5,6 +7,7 @@ def test_csv2port(data_regression) -> None:
     import gdsfactory as gf
 
     name = "straight"
-    csvpath = gf.CONFIG["gdsdir"] / f"{name}.ports"
+    csvpath = gf.PATH.gdsdir / f"{name}.ports"
+
     ports = csv2port(csvpath)
     data_regression.check(ports)
