@@ -1,18 +1,19 @@
+from __future__ import annotations
+
 import gdsfactory as gf
 
 
 def test_get_ports_sort_clockwise() -> None:
-    """
+    """.. code::
 
-    .. code::
+        3   4
+        |___|_
+    2 -|      |- 5
+       |      |
+    1 -|______|- 6
+        |   |
+        8   7
 
-             3   4
-             |___|_
-         2 -|      |- 5
-            |      |
-         1 -|______|- 6
-             |   |
-             8   7
     """
     c = gf.Component()
     nxn = gf.components.nxn(west=2, north=2, east=2, south=2)
@@ -28,17 +29,16 @@ def test_get_ports_sort_clockwise() -> None:
 
 
 def test_get_ports_sort_counter_clockwise() -> None:
-    """
+    """.. code::
 
-    .. code::
+        4   3
+        |___|_
+    5 -|      |- 2
+       |      |
+    6 -|______|- 1
+        |   |
+        7   8
 
-             4   3
-             |___|_
-         5 -|      |- 2
-            |      |
-         6 -|______|- 1
-             |   |
-             7   8
     """
     c = gf.Component()
     nxn = gf.components.nxn(west=2, north=2, east=2, south=2)
