@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import gdsfactory as gf
 
 
@@ -21,6 +23,16 @@ def test_is_on_2nm_grid() -> None:
     assert gf.snap.is_on_grid(2e-3, 2)
 
 
+def test_point_is_on_grid() -> None:
+    assert gf.snap.is_on_grid([0.5555, 0]) is False
+    assert gf.snap.is_on_grid([0.555, 0]) is True
+
+
+def test_point_is_on_2nm_grid() -> None:
+    assert gf.snap.is_on_grid([0.555, 0], nm=2) is False
+    assert gf.snap.is_on_grid([0.556, 0], nm=2) is True
+
+
 if __name__ == "__main__":
     test_is_on_2nm_grid()
     # print(snap_to_grid(1.1e-3))
