@@ -1,14 +1,16 @@
 """Generate the code from a GDS file based PDK."""
 
+from __future__ import annotations
+
 import datetime
 import pathlib
 from pathlib import Path
 from typing import Dict, Optional
 
-import gdspy
+import gdstk
 
 from gdsfactory.component import _timestamp2019
-from gdsfactory.config import CONFIG, logger
+from gdsfactory.config import PATH, logger
 from gdsfactory.name import clean_name
 from gdsfactory.types import PathType
 
@@ -34,6 +36,7 @@ def get_script(gdspath: PathType, module: Optional[str] = None) -> str:
     Args:
         gdspath: fixed cell gdspath.
         module: if any includes plot directive.
+
     """
     cell = clean_name(gdspath.stem)
     gdspath = gdspath.stem + gdspath.suffix
@@ -91,16 +94,16 @@ def get_import_gds_script(dirpath: PathType, module: Optional[str] = None) -> st
 
 
 def write_cells_recursively(
-    cell: gdspy.Cell,
+    cell: gdstk.Cell,
     unit: float = 1e-6,
     precision: float = 1e-9,
     timestamp: Optional[datetime.datetime] = _timestamp2019,
     dirpath: Optional[pathlib.Path] = None,
 ) -> Dict[str, Path]:
-    """Write gdspy cells recursively.
+    """Write gdstk cells recursively.
 
     Args:
-        cell: gdspy cell.
+        cell: gdstk cell.
         unit: unit size for objects in library. 1um by default.
         precision: for library dimensions (m). 1nm by default.
         timestamp: Defaults to 2019-10-25. If None uses current time.
@@ -108,28 +111,21 @@ def write_cells_recursively(
 
     Returns:
         gdspaths: dict of cell name to gdspath.
+
     """
     dirpath = dirpath or pathlib.Path.cwd()
     gdspaths = {}
 
-    for c in cell.get_dependencies():
+    for c in cell.dependencies(True):
         gdspath = f"{pathlib.Path(dirpath)/c.name}.gds"
-        lib = gdspy.GdsLibrary(unit=unit, precision=precision)
-        lib.write_gds(gdspath, cells=[c], timestamp=timestamp)
-        logger.info(f"Write GDS to {gdspath}")
+
+        lib = gdstk.Library(unit=unit, precision=precision)
+        lib.add(cell)
+        lib.add(*cell.dependencies(True))
+        lib.write_gds(gdspath)
 
         gdspaths[c.name] = gdspath
 
-        if c.get_dependencies():
-            gdspaths2 = write_cells_recursively(
-                cell=c,
-                unit=unit,
-                precision=precision,
-                timestamp=timestamp,
-                dirpath=dirpath,
-            )
-            gdspaths.update(gdspaths2)
-
     return gdspaths
 
 
@@ -156,11 +152,10 @@ def write_cells(
 
     Returns:
         gdspaths: dict of cell name to gdspath.
-    """
 
-    gdsii_lib = gdspy.GdsLibrary()
-    gdsii_lib.read_gds(gdspath)
-    top_level_cells = gdsii_lib.top_level()
+    """
+    cell = gdstk.read_gds(gdspath)
+    top_level_cells = cell.top_level()
 
     dirpath = dirpath or pathlib.Path.cwd()
     dirpath = pathlib.Path(dirpath)
@@ -172,9 +167,12 @@ def write_cells(
         if flatten:
             cell = cell.flatten()
         gdspath = f"{pathlib.Path(dirpath)/cell.name}.gds"
-        lib = gdspy.GdsLibrary(unit=unit, precision=precision)
-        gdspy.library.use_current_library = False
-        lib.write_gds(gdspath, cells=[cell], timestamp=timestamp)
+
+        lib = gdstk.Library(unit=unit, precision=precision)
+        lib.add(cell)
+        lib.add(*cell.dependencies(True))
+        lib.write_gds(gdspath)
+
         logger.info(f"Write {cell.name} to {gdspath}")
         gdspaths[cell.name] = gdspath
 
@@ -191,15 +189,16 @@ def write_cells(
 
 
 def test_write_cells():
-    gdspath = CONFIG["gdsdir"] / "mzi2x2.gds"
+    gdspath = PATH.gdsdir / "mzi2x2.gds"
     gdspaths = write_cells(gdspath=gdspath, dirpath="extra/gds")
     assert len(gdspaths) == 10, len(gdspaths)
 
 
 if __name__ == "__main__":
+    test_write_cells()
     import gdsfactory as gf
 
-    # gdspath = CONFIG["gdsdir"] / "mzi2x2.gds"
+    # gdspath = PATH.gdsdir / "mzi2x2.gds"
     # gf.show(gdspath)
     # gdspaths = write_cells(gdspath=gdspath, dirpath="extra/gds")
     # print(len(gdspaths))
